==> lhcsmapi-1.2.49.tar.gz: lhcsmapi-1.2.49/lhcsmapi/gui/pc/FgcPmSearchModuleMediator.py <==
from ipywidgets import Dropdown, Text, HBox, VBox, Select, Label, ToggleButtons
import getpass

from lhcsmapi.Time import Time
from lhcsmapi.gui.pc.FgcBrowserAction import FgcBrowserAction
from lhcsmapi.gui.pc.FgcPmSearchBaseModule import FgcPmSearchBaseModule
from lhcsmapi.metadata.SignalMetadata import SignalMetadata
from lhcsmapi.gui.ModuleMediator import ModuleMediator
from lhcsmapi.gui.qh.DateTimeBaseModule import DateTimeBaseModule
from lhcsmapi.gui.qh.QhBrowserAction import QhBrowserAction


class FgcPmSearchModuleMediator(ModuleMediator):

    def __init__(self, date_time_module: DateTimeBaseModule, fgc_pm_search_module: FgcPmSearchBaseModule,
                 circuit_type='RB', is_qps=True):
        self._circuit_type = circuit_type
        self._is_qps = is_qps
        # First row
        self.select_circuit_name_dropdown = Dropdown(
            options=SignalMetadata.get_circuit_names(circuit_type),
            description='Circuit name:',
            disabled=False,
        )

        self._date_time_module = date_time_module
        self._date_time_module.mediator = self

        self.done_by_txt = Text(placeholder='Your name', description='Done by:', value=getpass.getuser(),
                                disabled=True)

        self.analysis_mode_tgl_btn = ToggleButtons(
            options=['Automatic', 'Manual'],
            description='Analysis:',
            disabled=False,
            button_style='',
            tooltips=['Select automatic for automatic execution, comment, and acceptance.',
                      'Select manual to execute, comment, and accept each analysis manually.']
        )

        first_row = HBox(children=[self.select_circuit_name_dropdown, self._date_time_module.widget,
                                   self.analysis_mode_tgl_btn, self.done_by_txt])

        # Second row
        self._fgc_pm_search_module = fgc_pm_search_module
        self._fgc_pm_search_module.mediator = self
        second_row = fgc_pm_search_module.widget

        # Third row
        self.fgc_pm_sel = Select(
            options=[],
            rows=10,
            disabled=False
        )
        third_row = HBox(children=[Label(value='FGC PM Entries:'), self.fgc_pm_sel])

        # Final GUI
        self.widget = VBox(children=[first_row, second_row, third_row])

    def notify(self, sender: object, event: str) -> None:
        start_date_time = self._date_time_module.get_start_date_time()
        end_date_time = self._date_time_module.get_end_date_time()
        circuit_type = self.get_circuit_type()
        circuit_name = self.get_circuit_name()
        is_qps = self._is_qps

        if event == QhBrowserAction.DATE_CHANGED:
            pass
        elif event == FgcBrowserAction.FIND_BUTTON_CLICKED:
            self.fgc_pm_entries = self._fgc_pm_search_module.find_fgc_pm_entries(start_date_time, end_date_time,
                                                                                 circuit_type, circuit_name, is_qps)
            self.fgc_pm_sel.options = [Time.to_string(el[1]) for el in self.fgc_pm_entries]

        else:
            raise KeyError(f'Action {event} not supported!')

    def get_author(self):
        return self.done_by_txt.value

    def get_fgc_pm_entry(self):
        if len(self.fgc_pm_sel.options) == 0:
            raise ValueError(
                'The list of FGC PM Entries should contain at least one element. Please adjust circuit signal as well '
                'as start and end date.')
        else:
            return Time.to_unix_timestamp(self.fgc_pm_sel.value)

    def get_circuit_type(self):
        return self._circuit_type

    def get_circuit_name(self):
        return self.select_circuit_name_dropdown.value

    def is_automatic_mode(self):
        return self.analysis_mode_tgl_btn.value == 'Automatic'

==> lhcsmapi-1.2.111.tar.gz: lhcsmapi-1.2.111/lhcsmapi/gui/pc/FgcPmSearchModuleMediator.py <==
from ipywidgets import Dropdown, Text, HBox, VBox, Select, Label, ToggleButtons
import getpass

from lhcsmapi.Time import Time
from lhcsmapi.gui.ModuleMediator import ModuleMediator
from lhcsmapi.gui.pc.FgcBrowserAction import FgcBrowserAction
from lhcsmapi.gui.pc.FgcPmSearchBaseModule import FgcPmSearchBaseModule
from lhcsmapi.gui.qh.DateTimeBaseModule import DateTimeBaseModule
from lhcsmapi.gui.qh.QhBrowserAction import QhBrowserAction
from lhcsmapi.metadata.SignalMetadata import SignalMetadata



class FgcPmSearchModuleMediator(ModuleMediator):

    def __init__(self, date_time_module: DateTimeBaseModule, fgc_pm_search_module: FgcPmSearchBaseModule,
                 circuit_type='RB', is_qps=True):
        self._circuit_type = circuit_type
        self._is_qps = is_qps
        # First row
        self.select_circuit_name_dropdown = Dropdown(
            options=SignalMetadata.get_circuit_names(circuit_type),
            description='Circuit name:',
            disabled=False,
        )

        self._date_time_module = date_time_module
        self._date_time_module.mediator = self

        self.done_by_txt = Text(placeholder='Your name', description='Done by:', value=getpass.getuser(),
                                disabled=True)

        self.analysis_mode_tgl_btn = ToggleButtons(
            options=['Automatic', 'Manual'],
            description='Analysis:',
            disabled=False,
            button_style='',
            tooltips=['Select automatic for automatic execution, comment, and acceptance.',
                      'Select manual to execute, comment, and accept each analysis manually.']
        )

        first_row = HBox(children=[self.select_circuit_name_dropdown, self._date_time_module.widget])

        # Second row
        second_row = HBox(children=[self.analysis_mode_tgl_btn, self.done_by_txt])

        # Third row
        self._fgc_pm_search_module = fgc_pm_search_module
        self._fgc_pm_search_module.mediator = self
        third_row = fgc_pm_search_module.widget

        # Fourth row
        self.fgc_pm_sel = Select(
            options=[],
            rows=10,
            disabled=False
        )
        fourth_row = HBox(children=[Label(value='FGC PM Entries:'), self.fgc_pm_sel])

        # Final GUI
        self.widget = VBox(children=[first_row, second_row, third_row, fourth_row])

    def notify(self, sender: object, event: str) -> None:
        start_date_time = self._date_time_module.get_start_date_time()
        end_date_time = self._date_time_module.get_end_date_time()
        circuit_type = self.get_circuit_type()
        circuit_name = self.get_circuit_name()
        is_qps = self._is_qps

        if event == QhBrowserAction.DATE_CHANGED:
            pass
        elif event == FgcBrowserAction.FIND_BUTTON_CLICKED:
            self.fgc_pm_entries = self._fgc_pm_search_module.find_fgc_pm_entries(start_date_time, end_date_time,
                                                                                 circuit_type, circuit_name, is_qps)
            self.fgc_pm_sel.options = [Time.to_string(el[1]) for el in self.fgc_pm_entries]

        else:
            raise KeyError(f'Action {event} not supported!')

    def get_author(self):
        return self.done_by_txt.value

    def get_fgc_pm_entry(self):
        if len(self.fgc_pm_sel.options) == 0:
            raise ValueError(
                'The list of FGC PM Entries should contain at least one element. Please adjust circuit signal as well '
                'as start and end date.')
        else:
            return Time.to_unix_timestamp(self.fgc_pm_sel.value)

    def get_circuit_type(self):
        return self._circuit_type

    def get_circuit_name(self):
        return self.select_circuit_name_dropdown.value

    def is_automatic_mode(self):
        return self.analysis_mode_tgl_btn.value == 'Automatic'
